# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDatabaseMetricsCredentialsResult',
    'AwaitableGetDatabaseMetricsCredentialsResult',
    'get_database_metrics_credentials',
    'get_database_metrics_credentials_output',
]

@pulumi.output_type
class GetDatabaseMetricsCredentialsResult:
    """
    A collection of values returned by getDatabaseMetricsCredentials.
    """
    def __init__(__self__, id=None, password=None, username=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        """
        The password for accessing database metrics. This is marked as sensitive.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        The username for accessing database metrics.
        """
        return pulumi.get(self, "username")


class AwaitableGetDatabaseMetricsCredentialsResult(GetDatabaseMetricsCredentialsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseMetricsCredentialsResult(
            id=self.id,
            password=self.password,
            username=self.username)


def get_database_metrics_credentials(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseMetricsCredentialsResult:
    """
    Provides access to the metrics credentials for DigitalOcean database clusters. These credentials are account-wide and can be used to access metrics for any database cluster in the account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_database_metrics_credentials()
    pulumi.export("metricsUsername", example.username)
    pulumi.export("metricsPassword", example.password)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getDatabaseMetricsCredentials:getDatabaseMetricsCredentials', __args__, opts=opts, typ=GetDatabaseMetricsCredentialsResult).value

    return AwaitableGetDatabaseMetricsCredentialsResult(
        id=pulumi.get(__ret__, 'id'),
        password=pulumi.get(__ret__, 'password'),
        username=pulumi.get(__ret__, 'username'))
def get_database_metrics_credentials_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseMetricsCredentialsResult]:
    """
    Provides access to the metrics credentials for DigitalOcean database clusters. These credentials are account-wide and can be used to access metrics for any database cluster in the account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_database_metrics_credentials()
    pulumi.export("metricsUsername", example.username)
    pulumi.export("metricsPassword", example.password)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getDatabaseMetricsCredentials:getDatabaseMetricsCredentials', __args__, opts=opts, typ=GetDatabaseMetricsCredentialsResult)
    return __ret__.apply(lambda __response__: GetDatabaseMetricsCredentialsResult(
        id=pulumi.get(__response__, 'id'),
        password=pulumi.get(__response__, 'password'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseKafkaTopicArgs', 'DatabaseKafkaTopic']

@pulumi.input_type
class DatabaseKafkaTopicArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[_builtins.str],
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition_count: Optional[pulumi.Input[_builtins.int]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a DatabaseKafkaTopic resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the source database cluster. Note: This must be a Kafka cluster.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]] configs: A set of advanced configuration parameters. Defaults will be set for any of the parameters that are not included.
               The `config` block is documented below.
        :param pulumi.Input[_builtins.str] name: The name for the topic.
        :param pulumi.Input[_builtins.int] partition_count: The number of partitions for the topic. Default and minimum set at 3, maximum is 2048.
        :param pulumi.Input[_builtins.int] replication_factor: The number of nodes that topics are replicated across. Default and minimum set at 2, maximum is the number of nodes in the cluster.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        if configs is not None:
            pulumi.set(__self__, "configs", configs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition_count is not None:
            pulumi.set(__self__, "partition_count", partition_count)
        if replication_factor is not None:
            pulumi.set(__self__, "replication_factor", replication_factor)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the source database cluster. Note: This must be a Kafka cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter
    def configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]]]:
        """
        A set of advanced configuration parameters. Defaults will be set for any of the parameters that are not included.
        The `config` block is documented below.
        """
        return pulumi.get(self, "configs")

    @configs.setter
    def configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]]]):
        pulumi.set(self, "configs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the topic.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="partitionCount")
    def partition_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of partitions for the topic. Default and minimum set at 3, maximum is 2048.
        """
        return pulumi.get(self, "partition_count")

    @partition_count.setter
    def partition_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "partition_count", value)

    @_builtins.property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes that topics are replicated across. Default and minimum set at 2, maximum is the number of nodes in the cluster.
        """
        return pulumi.get(self, "replication_factor")

    @replication_factor.setter
    def replication_factor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "replication_factor", value)


@pulumi.input_type
class _DatabaseKafkaTopicState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition_count: Optional[pulumi.Input[_builtins.int]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseKafkaTopic resources.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the source database cluster. Note: This must be a Kafka cluster.
        :param pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]] configs: A set of advanced configuration parameters. Defaults will be set for any of the parameters that are not included.
               The `config` block is documented below.
        :param pulumi.Input[_builtins.str] name: The name for the topic.
        :param pulumi.Input[_builtins.int] partition_count: The number of partitions for the topic. Default and minimum set at 3, maximum is 2048.
        :param pulumi.Input[_builtins.int] replication_factor: The number of nodes that topics are replicated across. Default and minimum set at 2, maximum is the number of nodes in the cluster.
        :param pulumi.Input[_builtins.str] state: The current status of the topic. Possible values are 'active', 'configuring', and 'deleting'.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if configs is not None:
            pulumi.set(__self__, "configs", configs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if partition_count is not None:
            pulumi.set(__self__, "partition_count", partition_count)
        if replication_factor is not None:
            pulumi.set(__self__, "replication_factor", replication_factor)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the source database cluster. Note: This must be a Kafka cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter
    def configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]]]:
        """
        A set of advanced configuration parameters. Defaults will be set for any of the parameters that are not included.
        The `config` block is documented below.
        """
        return pulumi.get(self, "configs")

    @configs.setter
    def configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DatabaseKafkaTopicConfigArgs']]]]):
        pulumi.set(self, "configs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the topic.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="partitionCount")
    def partition_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of partitions for the topic. Default and minimum set at 3, maximum is 2048.
        """
        return pulumi.get(self, "partition_count")

    @partition_count.setter
    def partition_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "partition_count", value)

    @_builtins.property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of nodes that topics are replicated across. Default and minimum set at 2, maximum is the number of nodes in the cluster.
        """
        return pulumi.get(self, "replication_factor")

    @replication_factor.setter
    def replication_factor(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "replication_factor", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The current status of the topic. Possible values are 'active', 'configuring', and 'deleting'.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)


@pulumi.type_token("digitalocean:index/databaseKafkaTopic:DatabaseKafkaTopic")
class DatabaseKafkaTopic(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseKafkaTopicConfigArgs', 'DatabaseKafkaTopicConfigArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition_count: Optional[pulumi.Input[_builtins.int]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Provides a DigitalOcean Kafka topic for Kafka clusters.

        ## Example Usage

        ### Create a new Kafka topic
        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        kafka_example = digitalocean.DatabaseCluster("kafka-example",
            name="example-kafka-cluster",
            engine="kafka",
            version="3.5",
            size="db-s-2vcpu-2gb",
            region=digitalocean.Region.NYC1,
            node_count=3,
            tags=["production"])
        topic_01 = digitalocean.DatabaseKafkaTopic("topic-01",
            cluster_id=kafka_example.id,
            name="topic-01",
            partition_count=3,
            replication_factor=2,
            configs=[{
                "cleanup_policy": "compact",
                "compression_type": "uncompressed",
                "delete_retention_ms": "14000",
                "file_delete_delay_ms": "170000",
                "flush_messages": "92233",
                "flush_ms": "92233720368",
                "index_interval_bytes": "40962",
                "max_compaction_lag_ms": "9223372036854775807",
                "max_message_bytes": "1048588",
                "message_down_conversion_enable": True,
                "message_format_version": "3.0-IV1",
                "message_timestamp_difference_max_ms": "9223372036854775807",
                "message_timestamp_type": "log_append_time",
                "min_cleanable_dirty_ratio": 0.5,
                "min_compaction_lag_ms": "20000",
                "min_insync_replicas": 2,
                "preallocate": False,
                "retention_bytes": "-1",
                "retention_ms": "-1",
                "segment_bytes": "209715200",
                "segment_index_bytes": "10485760",
                "segment_jitter_ms": "0",
                "segment_ms": "604800000",
            }])
        ```

        ## Import

        Topics can be imported using the `id` of the source cluster and the `name` of the topic joined with a comma. For example:

        ```sh
        $ pulumi import digitalocean:index/databaseKafkaTopic:DatabaseKafkaTopic topic-01 245bcfd0-7f31-4ce6-a2bc-475a116cca97,topic-01
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the source database cluster. Note: This must be a Kafka cluster.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseKafkaTopicConfigArgs', 'DatabaseKafkaTopicConfigArgsDict']]]] configs: A set of advanced configuration parameters. Defaults will be set for any of the parameters that are not included.
               The `config` block is documented below.
        :param pulumi.Input[_builtins.str] name: The name for the topic.
        :param pulumi.Input[_builtins.int] partition_count: The number of partitions for the topic. Default and minimum set at 3, maximum is 2048.
        :param pulumi.Input[_builtins.int] replication_factor: The number of nodes that topics are replicated across. Default and minimum set at 2, maximum is the number of nodes in the cluster.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseKafkaTopicArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DigitalOcean Kafka topic for Kafka clusters.

        ## Example Usage

        ### Create a new Kafka topic
        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        kafka_example = digitalocean.DatabaseCluster("kafka-example",
            name="example-kafka-cluster",
            engine="kafka",
            version="3.5",
            size="db-s-2vcpu-2gb",
            region=digitalocean.Region.NYC1,
            node_count=3,
            tags=["production"])
        topic_01 = digitalocean.DatabaseKafkaTopic("topic-01",
            cluster_id=kafka_example.id,
            name="topic-01",
            partition_count=3,
            replication_factor=2,
            configs=[{
                "cleanup_policy": "compact",
                "compression_type": "uncompressed",
                "delete_retention_ms": "14000",
                "file_delete_delay_ms": "170000",
                "flush_messages": "92233",
                "flush_ms": "92233720368",
                "index_interval_bytes": "40962",
                "max_compaction_lag_ms": "9223372036854775807",
                "max_message_bytes": "1048588",
                "message_down_conversion_enable": True,
                "message_format_version": "3.0-IV1",
                "message_timestamp_difference_max_ms": "9223372036854775807",
                "message_timestamp_type": "log_append_time",
                "min_cleanable_dirty_ratio": 0.5,
                "min_compaction_lag_ms": "20000",
                "min_insync_replicas": 2,
                "preallocate": False,
                "retention_bytes": "-1",
                "retention_ms": "-1",
                "segment_bytes": "209715200",
                "segment_index_bytes": "10485760",
                "segment_jitter_ms": "0",
                "segment_ms": "604800000",
            }])
        ```

        ## Import

        Topics can be imported using the `id` of the source cluster and the `name` of the topic joined with a comma. For example:

        ```sh
        $ pulumi import digitalocean:index/databaseKafkaTopic:DatabaseKafkaTopic topic-01 245bcfd0-7f31-4ce6-a2bc-475a116cca97,topic-01
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseKafkaTopicArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseKafkaTopicArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseKafkaTopicConfigArgs', 'DatabaseKafkaTopicConfigArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 partition_count: Optional[pulumi.Input[_builtins.int]] = None,
                 replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseKafkaTopicArgs.__new__(DatabaseKafkaTopicArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["configs"] = configs
            __props__.__dict__["name"] = name
            __props__.__dict__["partition_count"] = partition_count
            __props__.__dict__["replication_factor"] = replication_factor
            __props__.__dict__["state"] = None
        super(DatabaseKafkaTopic, __self__).__init__(
            'digitalocean:index/databaseKafkaTopic:DatabaseKafkaTopic',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DatabaseKafkaTopicConfigArgs', 'DatabaseKafkaTopicConfigArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            partition_count: Optional[pulumi.Input[_builtins.int]] = None,
            replication_factor: Optional[pulumi.Input[_builtins.int]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None) -> 'DatabaseKafkaTopic':
        """
        Get an existing DatabaseKafkaTopic resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the source database cluster. Note: This must be a Kafka cluster.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DatabaseKafkaTopicConfigArgs', 'DatabaseKafkaTopicConfigArgsDict']]]] configs: A set of advanced configuration parameters. Defaults will be set for any of the parameters that are not included.
               The `config` block is documented below.
        :param pulumi.Input[_builtins.str] name: The name for the topic.
        :param pulumi.Input[_builtins.int] partition_count: The number of partitions for the topic. Default and minimum set at 3, maximum is 2048.
        :param pulumi.Input[_builtins.int] replication_factor: The number of nodes that topics are replicated across. Default and minimum set at 2, maximum is the number of nodes in the cluster.
        :param pulumi.Input[_builtins.str] state: The current status of the topic. Possible values are 'active', 'configuring', and 'deleting'.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseKafkaTopicState.__new__(_DatabaseKafkaTopicState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["configs"] = configs
        __props__.__dict__["name"] = name
        __props__.__dict__["partition_count"] = partition_count
        __props__.__dict__["replication_factor"] = replication_factor
        __props__.__dict__["state"] = state
        return DatabaseKafkaTopic(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the source database cluster. Note: This must be a Kafka cluster.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter
    def configs(self) -> pulumi.Output[Sequence['outputs.DatabaseKafkaTopicConfig']]:
        """
        A set of advanced configuration parameters. Defaults will be set for any of the parameters that are not included.
        The `config` block is documented below.
        """
        return pulumi.get(self, "configs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name for the topic.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="partitionCount")
    def partition_count(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of partitions for the topic. Default and minimum set at 3, maximum is 2048.
        """
        return pulumi.get(self, "partition_count")

    @_builtins.property
    @pulumi.getter(name="replicationFactor")
    def replication_factor(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of nodes that topics are replicated across. Default and minimum set at 2, maximum is the number of nodes in the cluster.
        """
        return pulumi.get(self, "replication_factor")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        The current status of the topic. Possible values are 'active', 'configuring', and 'deleting'.
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetGenaiAgentsByOpenaiApiKeyResult',
    'AwaitableGetGenaiAgentsByOpenaiApiKeyResult',
    'get_genai_agents_by_openai_api_key',
    'get_genai_agents_by_openai_api_key_output',
]

@pulumi.output_type
class GetGenaiAgentsByOpenaiApiKeyResult:
    """
    A collection of values returned by getGenaiAgentsByOpenaiApiKey.
    """
    def __init__(__self__, agents=None, id=None, uuid=None):
        if agents and not isinstance(agents, list):
            raise TypeError("Expected argument 'agents' to be a list")
        pulumi.set(__self__, "agents", agents)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if uuid and not isinstance(uuid, str):
            raise TypeError("Expected argument 'uuid' to be a str")
        pulumi.set(__self__, "uuid", uuid)

    @_builtins.property
    @pulumi.getter
    def agents(self) -> Sequence['outputs.GetGenaiAgentsByOpenaiApiKeyAgentResult']:
        return pulumi.get(self, "agents")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def uuid(self) -> _builtins.str:
        return pulumi.get(self, "uuid")


class AwaitableGetGenaiAgentsByOpenaiApiKeyResult(GetGenaiAgentsByOpenaiApiKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGenaiAgentsByOpenaiApiKeyResult(
            agents=self.agents,
            id=self.id,
            uuid=self.uuid)


def get_genai_agents_by_openai_api_key(uuid: Optional[_builtins.str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGenaiAgentsByOpenaiApiKeyResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['uuid'] = uuid
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getGenaiAgentsByOpenaiApiKey:getGenaiAgentsByOpenaiApiKey', __args__, opts=opts, typ=GetGenaiAgentsByOpenaiApiKeyResult).value

    return AwaitableGetGenaiAgentsByOpenaiApiKeyResult(
        agents=pulumi.get(__ret__, 'agents'),
        id=pulumi.get(__ret__, 'id'),
        uuid=pulumi.get(__ret__, 'uuid'))
def get_genai_agents_by_openai_api_key_output(uuid: Optional[pulumi.Input[_builtins.str]] = None,
                                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGenaiAgentsByOpenaiApiKeyResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['uuid'] = uuid
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getGenaiAgentsByOpenaiApiKey:getGenaiAgentsByOpenaiApiKey', __args__, opts=opts, typ=GetGenaiAgentsByOpenaiApiKeyResult)
    return __ret__.apply(lambda __response__: GetGenaiAgentsByOpenaiApiKeyResult(
        agents=pulumi.get(__response__, 'agents'),
        id=pulumi.get(__response__, 'id'),
        uuid=pulumi.get(__response__, 'uuid')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DropletAutoscaleArgs', 'DropletAutoscale']

@pulumi.input_type
class DropletAutoscaleArgs:
    def __init__(__self__, *,
                 config: pulumi.Input['DropletAutoscaleConfigArgs'],
                 droplet_template: pulumi.Input['DropletAutoscaleDropletTemplateArgs'],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DropletAutoscale resource.
        :param pulumi.Input['DropletAutoscaleConfigArgs'] config: The configuration parameters for Droplet Autoscale pool, the supported arguments are 
               documented below.
        :param pulumi.Input['DropletAutoscaleDropletTemplateArgs'] droplet_template: The droplet template parameters for Droplet Autoscale pool, the supported arguments 
               are documented below.
        :param pulumi.Input[_builtins.str] name: The name of the Droplet Autoscale pool.
        """
        pulumi.set(__self__, "config", config)
        pulumi.set(__self__, "droplet_template", droplet_template)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def config(self) -> pulumi.Input['DropletAutoscaleConfigArgs']:
        """
        The configuration parameters for Droplet Autoscale pool, the supported arguments are 
        documented below.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: pulumi.Input['DropletAutoscaleConfigArgs']):
        pulumi.set(self, "config", value)

    @_builtins.property
    @pulumi.getter(name="dropletTemplate")
    def droplet_template(self) -> pulumi.Input['DropletAutoscaleDropletTemplateArgs']:
        """
        The droplet template parameters for Droplet Autoscale pool, the supported arguments 
        are documented below.
        """
        return pulumi.get(self, "droplet_template")

    @droplet_template.setter
    def droplet_template(self, value: pulumi.Input['DropletAutoscaleDropletTemplateArgs']):
        pulumi.set(self, "droplet_template", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Droplet Autoscale pool.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DropletAutoscaleState:
    def __init__(__self__, *,
                 config: Optional[pulumi.Input['DropletAutoscaleConfigArgs']] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 current_utilizations: Optional[pulumi.Input[Sequence[pulumi.Input['DropletAutoscaleCurrentUtilizationArgs']]]] = None,
                 droplet_template: Optional[pulumi.Input['DropletAutoscaleDropletTemplateArgs']] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DropletAutoscale resources.
        :param pulumi.Input['DropletAutoscaleConfigArgs'] config: The configuration parameters for Droplet Autoscale pool, the supported arguments are 
               documented below.
        :param pulumi.Input[_builtins.str] created_at: Created at timestamp for the Droplet Autoscale pool.
        :param pulumi.Input[Sequence[pulumi.Input['DropletAutoscaleCurrentUtilizationArgs']]] current_utilizations: The current average resource utilization of the Droplet Autoscale pool, this attribute further
               embeds `memory` and `cpu` attributes to respectively report utilization data.
        :param pulumi.Input['DropletAutoscaleDropletTemplateArgs'] droplet_template: The droplet template parameters for Droplet Autoscale pool, the supported arguments 
               are documented below.
        :param pulumi.Input[_builtins.str] name: The name of the Droplet Autoscale pool.
        :param pulumi.Input[_builtins.str] status: Droplet Autoscale pool health status; this reflects if the pool is currently healthy and ready to accept
               traffic, or in an error state and needs user intervention.
        :param pulumi.Input[_builtins.str] updated_at: Updated at timestamp for the Droplet Autoscale pool.
        """
        if config is not None:
            pulumi.set(__self__, "config", config)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if current_utilizations is not None:
            pulumi.set(__self__, "current_utilizations", current_utilizations)
        if droplet_template is not None:
            pulumi.set(__self__, "droplet_template", droplet_template)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter
    def config(self) -> Optional[pulumi.Input['DropletAutoscaleConfigArgs']]:
        """
        The configuration parameters for Droplet Autoscale pool, the supported arguments are 
        documented below.
        """
        return pulumi.get(self, "config")

    @config.setter
    def config(self, value: Optional[pulumi.Input['DropletAutoscaleConfigArgs']]):
        pulumi.set(self, "config", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Created at timestamp for the Droplet Autoscale pool.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="currentUtilizations")
    def current_utilizations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DropletAutoscaleCurrentUtilizationArgs']]]]:
        """
        The current average resource utilization of the Droplet Autoscale pool, this attribute further
        embeds `memory` and `cpu` attributes to respectively report utilization data.
        """
        return pulumi.get(self, "current_utilizations")

    @current_utilizations.setter
    def current_utilizations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DropletAutoscaleCurrentUtilizationArgs']]]]):
        pulumi.set(self, "current_utilizations", value)

    @_builtins.property
    @pulumi.getter(name="dropletTemplate")
    def droplet_template(self) -> Optional[pulumi.Input['DropletAutoscaleDropletTemplateArgs']]:
        """
        The droplet template parameters for Droplet Autoscale pool, the supported arguments 
        are documented below.
        """
        return pulumi.get(self, "droplet_template")

    @droplet_template.setter
    def droplet_template(self, value: Optional[pulumi.Input['DropletAutoscaleDropletTemplateArgs']]):
        pulumi.set(self, "droplet_template", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Droplet Autoscale pool.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Droplet Autoscale pool health status; this reflects if the pool is currently healthy and ready to accept
        traffic, or in an error state and needs user intervention.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Updated at timestamp for the Droplet Autoscale pool.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("digitalocean:index/dropletAutoscale:DropletAutoscale")
class DropletAutoscale(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Union['DropletAutoscaleConfigArgs', 'DropletAutoscaleConfigArgsDict']]] = None,
                 droplet_template: Optional[pulumi.Input[Union['DropletAutoscaleDropletTemplateArgs', 'DropletAutoscaleDropletTemplateArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a DigitalOcean Droplet Autoscale resource. This can be used to create, modify,
        read and delete Droplet Autoscale pools.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean
        import pulumi_std as std

        my_ssh_key = digitalocean.SshKey("my-ssh-key",
            name="terraform-example",
            public_key=std.file(input="/Users/terraform/.ssh/id_rsa.pub").result)
        my_tag = digitalocean.Tag("my-tag", name="terraform-example")
        my_autoscale_pool = digitalocean.DropletAutoscale("my-autoscale-pool",
            name="terraform-example",
            config={
                "min_instances": 10,
                "max_instances": 50,
                "target_cpu_utilization": 0.5,
                "target_memory_utilization": 0.5,
                "cooldown_minutes": 5,
            },
            droplet_template={
                "size": "c-2",
                "region": "nyc3",
                "image": "ubuntu-24-04-x64",
                "tags": [my_tag.id],
                "ssh_keys": [my_ssh_key.id],
                "with_droplet_agent": True,
                "ipv6": True,
                "user_data": \"\"\"
        #cloud-config
        runcmd:
        - apt-get update
        - apt-get install -y stress-ng
        \"\"\",
            })
        ```

        ## Import

        Droplet Autoscale pools can be imported using their `id`, e.g.

        ```sh
        $ pulumi import digitalocean:index/dropletAutoscale:DropletAutoscale my-autoscale-pool 38e66834-d741-47ec-88e7-c70cbdcz0445
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DropletAutoscaleConfigArgs', 'DropletAutoscaleConfigArgsDict']] config: The configuration parameters for Droplet Autoscale pool, the supported arguments are 
               documented below.
        :param pulumi.Input[Union['DropletAutoscaleDropletTemplateArgs', 'DropletAutoscaleDropletTemplateArgsDict']] droplet_template: The droplet template parameters for Droplet Autoscale pool, the supported arguments 
               are documented below.
        :param pulumi.Input[_builtins.str] name: The name of the Droplet Autoscale pool.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DropletAutoscaleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DigitalOcean Droplet Autoscale resource. This can be used to create, modify,
        read and delete Droplet Autoscale pools.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean
        import pulumi_std as std

        my_ssh_key = digitalocean.SshKey("my-ssh-key",
            name="terraform-example",
            public_key=std.file(input="/Users/terraform/.ssh/id_rsa.pub").result)
        my_tag = digitalocean.Tag("my-tag", name="terraform-example")
        my_autoscale_pool = digitalocean.DropletAutoscale("my-autoscale-pool",
            name="terraform-example",
            config={
                "min_instances": 10,
                "max_instances": 50,
                "target_cpu_utilization": 0.5,
                "target_memory_utilization": 0.5,
                "cooldown_minutes": 5,
            },
            droplet_template={
                "size": "c-2",
                "region": "nyc3",
                "image": "ubuntu-24-04-x64",
                "tags": [my_tag.id],
                "ssh_keys": [my_ssh_key.id],
                "with_droplet_agent": True,
                "ipv6": True,
                "user_data": \"\"\"
        #cloud-config
        runcmd:
        - apt-get update
        - apt-get install -y stress-ng
        \"\"\",
            })
        ```

        ## Import

        Droplet Autoscale pools can be imported using their `id`, e.g.

        ```sh
        $ pulumi import digitalocean:index/dropletAutoscale:DropletAutoscale my-autoscale-pool 38e66834-d741-47ec-88e7-c70cbdcz0445
        ```

        :param str resource_name: The name of the resource.
        :param DropletAutoscaleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DropletAutoscaleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 config: Optional[pulumi.Input[Union['DropletAutoscaleConfigArgs', 'DropletAutoscaleConfigArgsDict']]] = None,
                 droplet_template: Optional[pulumi.Input[Union['DropletAutoscaleDropletTemplateArgs', 'DropletAutoscaleDropletTemplateArgsDict']]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DropletAutoscaleArgs.__new__(DropletAutoscaleArgs)

            if config is None and not opts.urn:
                raise TypeError("Missing required property 'config'")
            __props__.__dict__["config"] = config
            if droplet_template is None and not opts.urn:
                raise TypeError("Missing required property 'droplet_template'")
            __props__.__dict__["droplet_template"] = droplet_template
            __props__.__dict__["name"] = name
            __props__.__dict__["created_at"] = None
            __props__.__dict__["current_utilizations"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_at"] = None
        super(DropletAutoscale, __self__).__init__(
            'digitalocean:index/dropletAutoscale:DropletAutoscale',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            config: Optional[pulumi.Input[Union['DropletAutoscaleConfigArgs', 'DropletAutoscaleConfigArgsDict']]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            current_utilizations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['DropletAutoscaleCurrentUtilizationArgs', 'DropletAutoscaleCurrentUtilizationArgsDict']]]]] = None,
            droplet_template: Optional[pulumi.Input[Union['DropletAutoscaleDropletTemplateArgs', 'DropletAutoscaleDropletTemplateArgsDict']]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'DropletAutoscale':
        """
        Get an existing DropletAutoscale resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DropletAutoscaleConfigArgs', 'DropletAutoscaleConfigArgsDict']] config: The configuration parameters for Droplet Autoscale pool, the supported arguments are 
               documented below.
        :param pulumi.Input[_builtins.str] created_at: Created at timestamp for the Droplet Autoscale pool.
        :param pulumi.Input[Sequence[pulumi.Input[Union['DropletAutoscaleCurrentUtilizationArgs', 'DropletAutoscaleCurrentUtilizationArgsDict']]]] current_utilizations: The current average resource utilization of the Droplet Autoscale pool, this attribute further
               embeds `memory` and `cpu` attributes to respectively report utilization data.
        :param pulumi.Input[Union['DropletAutoscaleDropletTemplateArgs', 'DropletAutoscaleDropletTemplateArgsDict']] droplet_template: The droplet template parameters for Droplet Autoscale pool, the supported arguments 
               are documented below.
        :param pulumi.Input[_builtins.str] name: The name of the Droplet Autoscale pool.
        :param pulumi.Input[_builtins.str] status: Droplet Autoscale pool health status; this reflects if the pool is currently healthy and ready to accept
               traffic, or in an error state and needs user intervention.
        :param pulumi.Input[_builtins.str] updated_at: Updated at timestamp for the Droplet Autoscale pool.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DropletAutoscaleState.__new__(_DropletAutoscaleState)

        __props__.__dict__["config"] = config
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["current_utilizations"] = current_utilizations
        __props__.__dict__["droplet_template"] = droplet_template
        __props__.__dict__["name"] = name
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_at"] = updated_at
        return DropletAutoscale(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def config(self) -> pulumi.Output['outputs.DropletAutoscaleConfig']:
        """
        The configuration parameters for Droplet Autoscale pool, the supported arguments are 
        documented below.
        """
        return pulumi.get(self, "config")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Created at timestamp for the Droplet Autoscale pool.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="currentUtilizations")
    def current_utilizations(self) -> pulumi.Output[Sequence['outputs.DropletAutoscaleCurrentUtilization']]:
        """
        The current average resource utilization of the Droplet Autoscale pool, this attribute further
        embeds `memory` and `cpu` attributes to respectively report utilization data.
        """
        return pulumi.get(self, "current_utilizations")

    @_builtins.property
    @pulumi.getter(name="dropletTemplate")
    def droplet_template(self) -> pulumi.Output['outputs.DropletAutoscaleDropletTemplate']:
        """
        The droplet template parameters for Droplet Autoscale pool, the supported arguments 
        are documented below.
        """
        return pulumi.get(self, "droplet_template")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Droplet Autoscale pool.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Droplet Autoscale pool health status; this reflects if the pool is currently healthy and ready to accept
        traffic, or in an error state and needs user intervention.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Updated at timestamp for the Droplet Autoscale pool.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DatabaseDbArgs', 'DatabaseDb']

@pulumi.input_type
class DatabaseDbArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DatabaseDb resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the original source database cluster.
        :param pulumi.Input[_builtins.str] name: The name for the database.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the original source database cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the database.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _DatabaseDbState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseDb resources.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the original source database cluster.
        :param pulumi.Input[_builtins.str] name: The name for the database.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the original source database cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name for the database.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("digitalocean:index/databaseDb:DatabaseDb")
class DatabaseDb(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a DigitalOcean database resource. When creating a new database cluster, a default database with name `defaultdb` will be created. Then, this resource can be used to provide additional database inside the cluster.

        ## Example Usage

        ### Create a new PostgreSQL database
        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        postgres_example = digitalocean.DatabaseCluster("postgres-example",
            name="example-postgres-cluster",
            engine="pg",
            version="15",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1)
        database_example = digitalocean.DatabaseDb("database-example",
            cluster_id=postgres_example.id,
            name="foobar")
        ```

        ## Import

        Database can be imported using the `id` of the source database cluster

        and the `name` of the database joined with a comma. For example:

        ```sh
        $ pulumi import digitalocean:index/databaseDb:DatabaseDb database-example 245bcfd0-7f31-4ce6-a2bc-475a116cca97,foobar
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the original source database cluster.
        :param pulumi.Input[_builtins.str] name: The name for the database.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseDbArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DigitalOcean database resource. When creating a new database cluster, a default database with name `defaultdb` will be created. Then, this resource can be used to provide additional database inside the cluster.

        ## Example Usage

        ### Create a new PostgreSQL database
        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        postgres_example = digitalocean.DatabaseCluster("postgres-example",
            name="example-postgres-cluster",
            engine="pg",
            version="15",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1)
        database_example = digitalocean.DatabaseDb("database-example",
            cluster_id=postgres_example.id,
            name="foobar")
        ```

        ## Import

        Database can be imported using the `id` of the source database cluster

        and the `name` of the database joined with a comma. For example:

        ```sh
        $ pulumi import digitalocean:index/databaseDb:DatabaseDb database-example 245bcfd0-7f31-4ce6-a2bc-475a116cca97,foobar
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseDbArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseDbArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseDbArgs.__new__(DatabaseDbArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["name"] = name
        super(DatabaseDb, __self__).__init__(
            'digitalocean:index/databaseDb:DatabaseDb',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'DatabaseDb':
        """
        Get an existing DatabaseDb resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the original source database cluster.
        :param pulumi.Input[_builtins.str] name: The name for the database.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseDbState.__new__(_DatabaseDbState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["name"] = name
        return DatabaseDb(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the original source database cluster.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name for the database.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DatabaseOnlineMigrationArgs', 'DatabaseOnlineMigration']

@pulumi.input_type
class DatabaseOnlineMigrationArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[_builtins.str],
                 source: pulumi.Input['DatabaseOnlineMigrationSourceArgs'],
                 disable_ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 ignore_dbs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a DatabaseOnlineMigration resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input['DatabaseOnlineMigrationSourceArgs'] source: Configuration for migration
        :param pulumi.Input[_builtins.bool] disable_ssl: When set to true, enables SSL encryption when connecting to the source database.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ignore_dbs: A list of databases that should be ignored during migration.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "source", source)
        if disable_ssl is not None:
            pulumi.set(__self__, "disable_ssl", disable_ssl)
        if ignore_dbs is not None:
            pulumi.set(__self__, "ignore_dbs", ignore_dbs)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the target MySQL cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter
    def source(self) -> pulumi.Input['DatabaseOnlineMigrationSourceArgs']:
        """
        Configuration for migration
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: pulumi.Input['DatabaseOnlineMigrationSourceArgs']):
        pulumi.set(self, "source", value)

    @_builtins.property
    @pulumi.getter(name="disableSsl")
    def disable_ssl(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When set to true, enables SSL encryption when connecting to the source database.
        """
        return pulumi.get(self, "disable_ssl")

    @disable_ssl.setter
    def disable_ssl(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_ssl", value)

    @_builtins.property
    @pulumi.getter(name="ignoreDbs")
    def ignore_dbs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of databases that should be ignored during migration.
        """
        return pulumi.get(self, "ignore_dbs")

    @ignore_dbs.setter
    def ignore_dbs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ignore_dbs", value)


@pulumi.input_type
class _DatabaseOnlineMigrationState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 ignore_dbs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 source: Optional[pulumi.Input['DatabaseOnlineMigrationSourceArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DatabaseOnlineMigration resources.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input[_builtins.str] created_at: The date and time when the online migration was created
        :param pulumi.Input[_builtins.bool] disable_ssl: When set to true, enables SSL encryption when connecting to the source database.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ignore_dbs: A list of databases that should be ignored during migration.
        :param pulumi.Input['DatabaseOnlineMigrationSourceArgs'] source: Configuration for migration
        :param pulumi.Input[_builtins.str] status: The status of the online migration
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if disable_ssl is not None:
            pulumi.set(__self__, "disable_ssl", disable_ssl)
        if ignore_dbs is not None:
            pulumi.set(__self__, "ignore_dbs", ignore_dbs)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the target MySQL cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the online migration was created
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="disableSsl")
    def disable_ssl(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When set to true, enables SSL encryption when connecting to the source database.
        """
        return pulumi.get(self, "disable_ssl")

    @disable_ssl.setter
    def disable_ssl(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "disable_ssl", value)

    @_builtins.property
    @pulumi.getter(name="ignoreDbs")
    def ignore_dbs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        A list of databases that should be ignored during migration.
        """
        return pulumi.get(self, "ignore_dbs")

    @ignore_dbs.setter
    def ignore_dbs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ignore_dbs", value)

    @_builtins.property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input['DatabaseOnlineMigrationSourceArgs']]:
        """
        Configuration for migration
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input['DatabaseOnlineMigrationSourceArgs']]):
        pulumi.set(self, "source", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The status of the online migration
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("digitalocean:index/databaseOnlineMigration:DatabaseOnlineMigration")
class DatabaseOnlineMigration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 ignore_dbs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 source: Optional[pulumi.Input[Union['DatabaseOnlineMigrationSourceArgs', 'DatabaseOnlineMigrationSourceArgsDict']]] = None,
                 __props__=None):
        """
        Provides a virtual resource that can be used to start an online migration
        for a DigitalOcean managed database cluster. Migrating a cluster establishes a
        connection with an existing cluster and replicates its contents to the target
        cluster. If the existing database is continuously being written to, the migration
        process will continue for up to two weeks unless it is manually stopped.
        Online migration is only available for MySQL, PostgreSQL, Caching, and Valkey clusters.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        source = digitalocean.DatabaseCluster("source",
            name="st01",
            engine="mysql",
            version="8",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1,
            tags=["production"])
        destination = digitalocean.DatabaseCluster("destination",
            name="dt01",
            engine="mysql",
            version="8",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1,
            tags=["production"])
        source_db = digitalocean.DatabaseDb("source_db",
            cluster_id=source.id,
            name="terraform-db-om-source")
        foobar = digitalocean.DatabaseOnlineMigration("foobar",
            cluster_id=destination.id,
            source={
                "host": source.host,
                "db_name": source_db.name,
                "port": source.port,
                "username": source.user,
                "password": source.password,
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    destination,
                    source,
                    source_db,
                ]))
        ```

        ## Import

        A MySQL database cluster's online_migration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseOnlineMigration:DatabaseOnlineMigration example 4b62829a-9c42-465b-aaa3-84051048e712
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input[_builtins.bool] disable_ssl: When set to true, enables SSL encryption when connecting to the source database.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ignore_dbs: A list of databases that should be ignored during migration.
        :param pulumi.Input[Union['DatabaseOnlineMigrationSourceArgs', 'DatabaseOnlineMigrationSourceArgsDict']] source: Configuration for migration
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseOnlineMigrationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a virtual resource that can be used to start an online migration
        for a DigitalOcean managed database cluster. Migrating a cluster establishes a
        connection with an existing cluster and replicates its contents to the target
        cluster. If the existing database is continuously being written to, the migration
        process will continue for up to two weeks unless it is manually stopped.
        Online migration is only available for MySQL, PostgreSQL, Caching, and Valkey clusters.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        source = digitalocean.DatabaseCluster("source",
            name="st01",
            engine="mysql",
            version="8",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1,
            tags=["production"])
        destination = digitalocean.DatabaseCluster("destination",
            name="dt01",
            engine="mysql",
            version="8",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1,
            tags=["production"])
        source_db = digitalocean.DatabaseDb("source_db",
            cluster_id=source.id,
            name="terraform-db-om-source")
        foobar = digitalocean.DatabaseOnlineMigration("foobar",
            cluster_id=destination.id,
            source={
                "host": source.host,
                "db_name": source_db.name,
                "port": source.port,
                "username": source.user,
                "password": source.password,
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    destination,
                    source,
                    source_db,
                ]))
        ```

        ## Import

        A MySQL database cluster's online_migration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseOnlineMigration:DatabaseOnlineMigration example 4b62829a-9c42-465b-aaa3-84051048e712
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseOnlineMigrationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseOnlineMigrationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 disable_ssl: Optional[pulumi.Input[_builtins.bool]] = None,
                 ignore_dbs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 source: Optional[pulumi.Input[Union['DatabaseOnlineMigrationSourceArgs', 'DatabaseOnlineMigrationSourceArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseOnlineMigrationArgs.__new__(DatabaseOnlineMigrationArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["disable_ssl"] = disable_ssl
            __props__.__dict__["ignore_dbs"] = ignore_dbs
            if source is None and not opts.urn:
                raise TypeError("Missing required property 'source'")
            __props__.__dict__["source"] = source
            __props__.__dict__["created_at"] = None
            __props__.__dict__["status"] = None
        super(DatabaseOnlineMigration, __self__).__init__(
            'digitalocean:index/databaseOnlineMigration:DatabaseOnlineMigration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            disable_ssl: Optional[pulumi.Input[_builtins.bool]] = None,
            ignore_dbs: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            source: Optional[pulumi.Input[Union['DatabaseOnlineMigrationSourceArgs', 'DatabaseOnlineMigrationSourceArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'DatabaseOnlineMigration':
        """
        Get an existing DatabaseOnlineMigration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input[_builtins.str] created_at: The date and time when the online migration was created
        :param pulumi.Input[_builtins.bool] disable_ssl: When set to true, enables SSL encryption when connecting to the source database.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ignore_dbs: A list of databases that should be ignored during migration.
        :param pulumi.Input[Union['DatabaseOnlineMigrationSourceArgs', 'DatabaseOnlineMigrationSourceArgsDict']] source: Configuration for migration
        :param pulumi.Input[_builtins.str] status: The status of the online migration
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseOnlineMigrationState.__new__(_DatabaseOnlineMigrationState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["disable_ssl"] = disable_ssl
        __props__.__dict__["ignore_dbs"] = ignore_dbs
        __props__.__dict__["source"] = source
        __props__.__dict__["status"] = status
        return DatabaseOnlineMigration(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the target MySQL cluster.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the online migration was created
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="disableSsl")
    def disable_ssl(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        When set to true, enables SSL encryption when connecting to the source database.
        """
        return pulumi.get(self, "disable_ssl")

    @_builtins.property
    @pulumi.getter(name="ignoreDbs")
    def ignore_dbs(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        A list of databases that should be ignored during migration.
        """
        return pulumi.get(self, "ignore_dbs")

    @_builtins.property
    @pulumi.getter
    def source(self) -> pulumi.Output['outputs.DatabaseOnlineMigrationSource']:
        """
        Configuration for migration
        """
        return pulumi.get(self, "source")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The status of the online migration
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetGenaiAgentsResult',
    'AwaitableGetGenaiAgentsResult',
    'get_genai_agents',
    'get_genai_agents_output',
]

@pulumi.output_type
class GetGenaiAgentsResult:
    """
    A collection of values returned by getGenaiAgents.
    """
    def __init__(__self__, agents=None, filters=None, id=None, only_deployed=None, sorts=None):
        if agents and not isinstance(agents, list):
            raise TypeError("Expected argument 'agents' to be a list")
        pulumi.set(__self__, "agents", agents)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if only_deployed and not isinstance(only_deployed, bool):
            raise TypeError("Expected argument 'only_deployed' to be a bool")
        pulumi.set(__self__, "only_deployed", only_deployed)
        if sorts and not isinstance(sorts, list):
            raise TypeError("Expected argument 'sorts' to be a list")
        pulumi.set(__self__, "sorts", sorts)

    @_builtins.property
    @pulumi.getter
    def agents(self) -> Sequence['outputs.GetGenaiAgentsAgentResult']:
        return pulumi.get(self, "agents")

    @_builtins.property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetGenaiAgentsFilterResult']]:
        return pulumi.get(self, "filters")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="onlyDeployed")
    def only_deployed(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "only_deployed")

    @_builtins.property
    @pulumi.getter
    def sorts(self) -> Optional[Sequence['outputs.GetGenaiAgentsSortResult']]:
        return pulumi.get(self, "sorts")


class AwaitableGetGenaiAgentsResult(GetGenaiAgentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGenaiAgentsResult(
            agents=self.agents,
            filters=self.filters,
            id=self.id,
            only_deployed=self.only_deployed,
            sorts=self.sorts)


def get_genai_agents(filters: Optional[Sequence[Union['GetGenaiAgentsFilterArgs', 'GetGenaiAgentsFilterArgsDict']]] = None,
                     only_deployed: Optional[_builtins.bool] = None,
                     sorts: Optional[Sequence[Union['GetGenaiAgentsSortArgs', 'GetGenaiAgentsSortArgsDict']]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGenaiAgentsResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['onlyDeployed'] = only_deployed
    __args__['sorts'] = sorts
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getGenaiAgents:getGenaiAgents', __args__, opts=opts, typ=GetGenaiAgentsResult).value

    return AwaitableGetGenaiAgentsResult(
        agents=pulumi.get(__ret__, 'agents'),
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        only_deployed=pulumi.get(__ret__, 'only_deployed'),
        sorts=pulumi.get(__ret__, 'sorts'))
def get_genai_agents_output(filters: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentsFilterArgs', 'GetGenaiAgentsFilterArgsDict']]]]] = None,
                            only_deployed: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                            sorts: Optional[pulumi.Input[Optional[Sequence[Union['GetGenaiAgentsSortArgs', 'GetGenaiAgentsSortArgsDict']]]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGenaiAgentsResult]:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['onlyDeployed'] = only_deployed
    __args__['sorts'] = sorts
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getGenaiAgents:getGenaiAgents', __args__, opts=opts, typ=GetGenaiAgentsResult)
    return __ret__.apply(lambda __response__: GetGenaiAgentsResult(
        agents=pulumi.get(__response__, 'agents'),
        filters=pulumi.get(__response__, 'filters'),
        id=pulumi.get(__response__, 'id'),
        only_deployed=pulumi.get(__response__, 'only_deployed'),
        sorts=pulumi.get(__response__, 'sorts')))
